"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable no-console */
/* eslint-disable import/prefer-default-export */
var fs_extra_1 = require("fs-extra");
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var path_1 = require("path");
var ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
var paths_1 = require("../config/paths");
var parseTemplateStr_1 = tslib_1.__importDefault(require("./parseTemplateStr"));
var genDoczFiles_1 = tslib_1.__importDefault(require("./genDoczFiles"));
/**
 * 生成package.json文件
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
function genPackageFile(projectPath, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var packagePath, packageInfo;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    packagePath = path_1.resolve(projectPath, 'package.json');
                    return [4 /*yield*/, fs_extra_1.readJSON(packagePath)];
                case 1:
                    packageInfo = _a.sent();
                    packageInfo.version = options.packageVersion;
                    packageInfo.name = options.packageName;
                    packageInfo.description = options.packageDescription;
                    packageInfo.files = ['dist', 'assets'];
                    packageInfo['umd:main'] = "dist/" + ts_lib_scripts_utils_1.safePackageName(options.packageName) + ".umd.production.js";
                    packageInfo.module = "dist/" + ts_lib_scripts_utils_1.safePackageName(options.packageName) + ".es.production.js";
                    return [4 /*yield*/, fs_extra_1.outputJSON(packagePath, packageInfo, {
                            spaces: 2,
                        })];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
exports.genPackageFile = genPackageFile;
/**
 * 生成README.md文档
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
function genREADMEFile(projectPath, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var readmePath, content;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    readmePath = path_1.resolve(projectPath, 'README.md');
                    return [4 /*yield*/, fs_extra_1.readFile(readmePath, 'utf-8')];
                case 1:
                    content = _a.sent();
                    return [4 /*yield*/, fs_extra_1.writeFile(readmePath, parseTemplateStr_1.default(content, tslib_1.__assign({}, options, { packageDescription: options.packageDescription ||
                                '这是由[ts-lib-scripts](https://github.com/sinoui/ts-lib-scripts)创建的TypeScript库项目。' })))];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
exports.genREADMEFile = genREADMEFile;
/**
 * 生成LICENSE文件
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
function genLicenseFile(projectPath, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var licensePath, content;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    licensePath = path_1.resolve(projectPath, 'LICENSE');
                    return [4 /*yield*/, fs_extra_1.readFile(licensePath, 'utf-8')];
                case 1:
                    content = _a.sent();
                    return [4 /*yield*/, fs_extra_1.writeFile(licensePath, parseTemplateStr_1.default(content, {
                            time: new Date().getFullYear(),
                            author: options.author || '',
                        }))];
                case 2:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
exports.genLicenseFile = genLicenseFile;
/**
 * 生成项目
 *
 * @param options 配置
 */
function genProject(options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var projectPath, exists;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    projectPath = paths_1.resolveRoot(options.projectName);
                    return [4 /*yield*/, fs_extra_1.pathExists(projectPath)];
                case 1:
                    exists = _a.sent();
                    if (exists) {
                        console.error(chalk_1.default.red("\u5DF2\u7ECF\u5B58\u5728" + options.projectName + "\u6587\u4EF6\u5939\uFF0C\u8BF7\u9009\u62E9\u4E00\u4E2A\u65B0\u7684\u9879\u76EE\u540D\u79F0\u3002"));
                        process.exit(1);
                    }
                    return [4 /*yield*/, fs_extra_1.copy(paths_1.COMMON_TEMPLATE_PATH, projectPath)];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, fs_extra_1.copy(options.react ? paths_1.REACT_TEMPLATE_PATH : paths_1.TEMPLATE_PATH, projectPath)];
                case 3:
                    _a.sent();
                    return [4 /*yield*/, fs_extra_1.copy(paths_1.GIT_IGNORE_FILE_PATH, path_1.resolve(projectPath, '.gitignore'))];
                case 4:
                    _a.sent();
                    return [4 /*yield*/, genPackageFile(projectPath, options)];
                case 5:
                    _a.sent();
                    return [4 /*yield*/, genREADMEFile(projectPath, options)];
                case 6:
                    _a.sent();
                    return [4 /*yield*/, genLicenseFile(projectPath, options)];
                case 7:
                    _a.sent();
                    if (!options.docz) return [3 /*break*/, 9];
                    return [4 /*yield*/, genDoczFiles_1.default(projectPath, options)];
                case 8:
                    _a.sent();
                    _a.label = 9;
                case 9: return [2 /*return*/];
            }
        });
    });
}
exports.genProject = genProject;
//# sourceMappingURL=genProject.js.map