"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/* eslint-disable import/prefer-default-export */
/* eslint-disable no-console */
var chalk_1 = tslib_1.__importDefault(require("chalk"));
var ora_1 = tslib_1.__importDefault(require("ora"));
var enquirer_1 = require("enquirer");
var ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
var validatePackageName_1 = require("./validatePackageName");
var getOptions_1 = require("./getOptions");
var genProject_1 = require("./genProject");
var paths_1 = require("../config/paths");
var isCmdInstalled_1 = tslib_1.__importDefault(require("./isCmdInstalled"));
var createGitRepository_1 = tslib_1.__importDefault(require("./createGitRepository"));
var gitCommit_1 = tslib_1.__importDefault(require("./gitCommit"));
var installDeps_1 = tslib_1.__importDefault(require("./installDeps"));
var execa = require("execa");
/**
 * 创建项目
 *
 * @param projectName 项目名称
 * @param program 命令行对象
 */
function create(projectNameConfig, program) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var projectName, packageName, options, spinner, error_1, projectPath, gitCreated, openWithCode;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    projectName = projectNameConfig.startsWith('@')
                        ? projectNameConfig.substr(projectNameConfig.indexOf('/') + 1)
                        : projectNameConfig;
                    packageName = (program.packageName || projectNameConfig);
                    if (!validatePackageName_1.validatePackageName(packageName)) {
                        process.exit(1);
                    }
                    return [4 /*yield*/, getOptions_1.getOptions(projectName, packageName, program)];
                case 1:
                    options = _a.sent();
                    spinner = ora_1.default().start();
                    spinner.start('正在生成项目...');
                    _a.label = 2;
                case 2:
                    _a.trys.push([2, 4, , 5]);
                    return [4 /*yield*/, genProject_1.genProject(options)];
                case 3:
                    _a.sent();
                    spinner.succeed("\u5DF2\u751F\u6210\u9879\u76EE " + chalk_1.default.green(packageName));
                    return [3 /*break*/, 5];
                case 4:
                    error_1 = _a.sent();
                    spinner.fail('生成项目失败');
                    ts_lib_scripts_utils_1.logError(error_1);
                    process.exit(1);
                    return [3 /*break*/, 5];
                case 5:
                    projectPath = paths_1.resolveRoot(options.projectName);
                    gitCreated = createGitRepository_1.default(projectPath);
                    return [4 /*yield*/, installDeps_1.default(spinner, options)];
                case 6:
                    _a.sent();
                    if (gitCreated) {
                        try {
                            gitCommit_1.default(projectPath);
                        }
                        catch (error) {
                            // 忽略git提交失败
                        }
                    }
                    if (!isCmdInstalled_1.default('code')) return [3 /*break*/, 9];
                    console.log();
                    return [4 /*yield*/, enquirer_1.prompt({
                            type: 'confirm',
                            name: 'openWithCode',
                            message: '使用vscode打开项目？',
                            initial: 'Y',
                        })];
                case 7:
                    openWithCode = (_a.sent()).openWithCode;
                    if (!openWithCode) return [3 /*break*/, 9];
                    return [4 /*yield*/, execa('code', [projectName])];
                case 8:
                    _a.sent();
                    _a.label = 9;
                case 9:
                    process.exit(0);
                    return [2 /*return*/];
            }
        });
    });
}
exports.default = create;
//# sourceMappingURL=index.js.map