"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var messages_1 = require("./messages");
var constants_1 = require("./constants");
var getInstallDepsCmd_1 = tslib_1.__importDefault(require("./getInstallDepsCmd"));
var paths_1 = require("../config/paths");
var getInstallCmd_1 = tslib_1.__importDefault(require("./getInstallCmd"));
var execa = require("execa");
function getDevPendencies(options) {
    return constants_1.devDependencies.concat((options.react ? constants_1.devDependenciesForReact : []), (options.docz ? constants_1.devDependenciesForDocz : []), (options.doczGithubPages ? constants_1.devDependenciesForGhpages : []));
}
/**
 * 执行安装依赖的命令
 *
 * @param projectName 项目名称
 * @param deps 依赖
 * @param isDev 是否是开发依赖
 */
function execInstallDeps(projectName, deps, isDev) {
    if (isDev === void 0) { isDev = false; }
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var cmd, args;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    cmd = getInstallCmd_1.default();
                    args = [
                        cmd === 'npm' ? 'i' : 'add'
                    ].concat(deps, [
                        isDev ? '--dev' : '',
                        cmd === 'npm' ? '--save' : '',
                    ]).filter(Boolean);
                    return [4 /*yield*/, execa(cmd, args, {
                            cwd: paths_1.resolveRoot(projectName),
                        })];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
/**
 * 安装依赖
 *
 * @param {CreateOptions} options
 */
function installDeps(spinner, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var projectName, devDeps, error_1;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    projectName = options.projectName;
                    devDeps = getDevPendencies(options);
                    spinner.start(messages_1.dependenciesMessage(constants_1.dependencies, devDeps));
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 4, , 5]);
                    return [4 /*yield*/, execInstallDeps(projectName, constants_1.dependencies)];
                case 2:
                    _a.sent();
                    return [4 /*yield*/, execInstallDeps(projectName, devDeps, true)];
                case 3:
                    _a.sent();
                    spinner.succeed('安装依赖包');
                    messages_1.successMessage(getInstallCmd_1.default(), projectName);
                    return [3 /*break*/, 5];
                case 4:
                    error_1 = _a.sent();
                    spinner.fail("\u5B89\u88C5\u4F9D\u8D56\u5931\u8D25");
                    messages_1.failureMessage([
                        getInstallDepsCmd_1.default(constants_1.dependencies),
                        getInstallDepsCmd_1.default(devDeps, true),
                    ]);
                    process.exit(1);
                    return [3 /*break*/, 5];
                case 5: return [2 /*return*/];
            }
        });
    });
}
exports.default = installDeps;
//# sourceMappingURL=installDeps.js.map